@@ -1,14 +1,16 @@
-print "\nSeeing if you have some optional utilities ...\n\n";
 $HOSTNAME = &wherecheck('Finding hostname', 'hostname');
-
-print "\nChecking some system facilities I really could use ...\n\n";
 $DEF_MCANALARM = &yncheck('Can we use alarm()?', 'alarm 0;');
 &prompt(<<"EOF", "") if (!$DEF_MCANALARM);
 Let me guess. You're not using a Unix Perl.
 
-alarm() is no longer required for install, but you should be warned that
-you cannot use HTTP/1.1 Keep-Alive connections without it. Also, alarm()
+alarm() is no longer required for install, but you should be warned that it
 allows better process control, which reduces the chance of system overload.
+
+More importantly, if you intend to use inetd HTTPi on a system that times
+inetd processes out if sockets remain open, you will be running a very
+unstable server without alarm() support. (This is only an issue with inetd
+HTTPi, not Demonic or xinetd HTTPis.)
+
 You can still install HTTPi, but consider running this on a system that
 supports alarm() in its Perl port.
 
@@ -29,11 +31,28 @@ unless you're darn certain that they'll all be configured the same way.
 IF YOU'RE USING CONFIGURE TO BUILD MULTIPLE INSTANCES OF HTTPi ON MULTIPLE
 IP ADDRESSES (xinetd/Demonic only), THIS *MUST* BE DIFFERENT IN EACH CASE!
 
-WARNING: If you're doing a full install, including modifying inetd (or
-whatever)'s config files, THIS MUST BE AN ABSOLUTE PATH AS WELL!
+WARNING TO xinetd/inetd INSTALLERS: If you are doing a full install to update
+(x)inetd's config files simultaneously, THIS MUST BE AN ABSOLUTE PATH!
 
 Install path?
 EOF
+unless ($DEF_MDEMONIC) {
+	$DEF_AF_INET = &prompt(<<"EOF", 2, 1);
+In an effort to make non-Demonic HTTPi less Unix-oriented (you decide if this
+actually helps any), the one item in HTTPi that used to be a hardcoded
+network constant now actually makes an effort to be portable. If you know
+that your system's AF_INET macro is something other than two, enter it here.
+(I have yet to find an OS where it wasn't, but I'm sure they're out there,
+although it was 2 on AIX, SCO, HP/UX, Solaris, NetBSD and Linux.) 
+
+If you don't know what this is, accept the default -- it's probably correct.
+
+Demonic already gets this information in other ways, so its configure script
+doesn't need to ask (besides, it's pretty Unix-centric as it is anyhow).
+
+System AF_INET constant (nearly invariably 2)?
+EOF
+}
 $DEF_HTDOCS_PATH = &prompt(<<"EOF", "/usr/local/htdocs", 1);
 Where do you want the server to serve documents from? All files that HTTPi
 will make available, executables included, must be under this tree (except
@@ -82,41 +101,6 @@ five-character timezone here (e.g., if you're on Pacific time, like I am,
 enter -0800 for 8 hours behind Greenwich mean).
 EOF
 
-print "You can't use alarm(), so no HTTP/1.1 for you.\n\n"
-	unless ($DEF_MCANALARM);
-
-$DEF_HTTP11WAIT = &prompt(<<"EOF", "n", 1) unless (!$DEF_MCANALARM);
-HTTPi supports HTTP/1.1 persistent connections, but very few clients do right
-now. It's nice to have though, for those that do, and it means that it will
-spawn fewer processes sum total if the client is nice enough to do all its
-requests on a single socket.
-
-The downside is, due to the current implementation, clients that do not
-properly support HTTP/1.1 persistent connections (but advertise they do) will
-have slightly slower access. As of this writing, Netscape is particularly bad
-on this point. Unfortunately, there's nothing the server can do about that.
-
-Enable HTTP/1.1 support?
-EOF
-$DEF_HTTP11WAIT = ($DEF_HTTP11WAIT eq 'y') ? 1 : 0;
-
-$DEF_TIME_OUT = &prompt(<<"EOF", "1", 1) unless (!$DEF_HTTP11WAIT);
-And speaking of supposedly compliant clients ...
-
-HTTPi has a funky kludge in it to better handle supposedly HTTP/1.1-compliant
-clients that really aren't by waiting a specified number of seconds before
-dying off to see if another request comes down the pike. Increasing this
-number makes it more tolerant of slower clients, but degrades overall
-connection speed. This only applies to clients that advertise the
-"Connection: Keep-Alive" header. The default should be satisfactory here.
-
-SPECIAL CASE: If you answer zero to this question, it will wait forever.
-This is probably NOT what you want, but I guess one of you might ...
-
-Number of seconds to wait for slow HTTP/1.1 clients?
-EOF
-$DEF_TIME_OUT += 0;
-
 $DEF_MRESTRICTIONS = &prompt(<<"EOF", "y", 1);
 HTTPi's answer to .htaccess and access control is the restriction matrix, 
 allowing access control based on IP address, agent/browser type, and, in
@@ -130,9 +114,9 @@ like TCP wrappers are probably faster. xinetd also has IP address-based
 restriction built in. In those cases, you would probably do better without
 the restriction matrix involved.
 
-The settings for the restriction matrix are hardcoded into httpi.in. If you
-choose to enable this option, you must edit httpi.in to change your settings.
-Please refer to the programming manual.
+The settings for the restriction matrix are hardcoded into uservar.in, and
+to change your settings you must edit that file and rebuild HTTPi. For help,
+please refer to the user's manual.
 
 Enable restriction matrix?
 EOF
@@ -184,9 +168,7 @@ subroutines, including HTTP negotiation and logging subroutines.
 The major disadvantages:
 	* EVERY EXECUTABLE HTTPi RUNS HAS TO BE IN PERL. NO EXCEPTIONS! If you
 must run a precompiled binary, write a Perl wrapper, and have HTTPi run that.
-	* Still experimental.
 
-This is a new, experimental hack, so be wary, test thoroughly, and report bugs.
 Please read the docs, there's important information in there about this!
 Enable HTTPerl?
 EOF
@@ -216,9 +198,9 @@ not enabled by default. If your HTTPi supports it (both xinetd and Demonic
 do), you may wish to consider IP-based virtual hosting where you can do
 multihoming with individual HTTPi processes as an alternative.
 
-The settings for IP-less virtual hosting are hardcoded into httpi.in. If you
-choose to enable this option, you must edit httpi.in to change your settings.
-Please refer to the programming manual.
+The settings for IP-less virtual hosting are hardcoded into uservar.in, and
+to change your settings you must edit that file and rebuild HTTPi. For help,
+please refer to the user's manual.
 
 Enable host name redirects?
 EOF
@@ -248,6 +230,96 @@ EOF
 	$DEF_MUSERFS = ($q eq 'y') ? 1 : 0;
 }
 
+$q = &prompt(<<"EOF", "n", 1);
+HTTPi now enables preparsing of selected content types. With the new preparse
+module loaded, you can:
+
+	* insert inline Perl with the <perl></perl> tags and access server
+	  internals
+
+Preparsing is done only on files with extensions .sht, .shtm and .shtml, 
+unless you say otherwise.
+
+Because this runs as the UID of the webserver, this can be a VERY BIG security
+hole if enabled with the user filesystem. Enable only if you really trust
+your users, or if you will be the sole person creating content for HTTPi (or
+if you're running HTTPi as some unprivileged user that can't do anything
+antisocial). Enable only under severe, serious advisement!
+
+For information on how to program with inline Perl, see the programming manual.
+
+Enable preparsing?
+EOF
+$DEF_MPREPARSE = ($q eq 'y') ? 1 : 0;
+unless ($DEF_MPREPARSE) {
+	print <<"EOF";
+You said no preparsing, so I won't ask you any more questions about that.
+Neener, neener; et la neener. That's French for phooey on you.
+
+EOF
+} else {
+	$q = &prompt(<<"EOF", "n", 1);
+You may have all HTML files, or just ones with the .sht, .shtm or .shtml
+extensions preparsed for inline Perl. Preparsing is not that big of a
+performance hit, but you may not want it occurring everywhere just the same,
+so the default only parses .sht, .shtm and .shtml.
+
+Parse all HTML files?
+EOF
+	$DEF_PREGEXPA = ($q eq 'y') ? '?' : '';
+#	$DEF_PREGEXPB = ($q eq 'y') ? '' : '?';
+}
+
+if ($DEF_MCANALARM) {
+	$q = &prompt(<<"EOF", "n", 1);
+Now the ugly kludge section. This is really only relevant to inetd users, but
+this option may be occasionally useful to Demonic and xinetd installs.
+
+Some inetds will time out, and then shut down, services that hold sockets
+open for longer than a critical period of time (Linux inetd is the most
+notorious). This usually happens when a very large file is being downloaded
+over a very slow link. The upshot is, HTTPi will be turned off by inetd and
+fail to respond to requests until inetd gets another -HUP signal. This might
+be the basis of a nasty DoS attack, so here it is as a configure option.
+HTTPi will simply kill the link if too much time passes, and save itself, if
+this option is enabled. You can adjust the timeout with the next question.
+You might also want to enable this if you get besieged with requests that
+just hang sockets up on your system, but you don't need it if you're not
+running inetd HTTPi.
+
+Note that many inetds will not require this (AIX and HP/UX don't seem to).
+Don't turn it on unless you think it's necessary for your OS or security.
+
+Auto-kill the link on slow data transfers?
+EOF
+	$DEF_MAUTOKILL = ($q eq 'y') ? 1 : 0;
+	if ($DEF_MAUTOKILL) {
+		$DEF_AK_TIMEOUT = &prompt(<<"EOF", "25", 1);
+Enter the timeout (in seconds) before HTTPi should auto-kill the link. This
+is system dependent. Some inetds will kick HTTPi down after as little as
+thirty seconds but most are usually up to sixty. Tune this to whatever seems
+to give the best performance and stability, which usually is five or ten
+seconds before inetd will actually close the port down.
+
+If this is just for security purposes, set it to whatever you like. Sixty
+seconds seems good for not-too-busy sites with not-too-big files.
+
+Auto-kill timeout?
+EOF
+	} else {
+		print <<"EOF";
+Murderous tendencies quelled.
+
+EOF
+	}
+} else {
+	print <<"EOF";
+You don't support alarm(), so I can't give you the ugly kludge for keeping
+inetd HTTPis stable on certain platforms (notably Linux) even though you
+might need it.
+
+EOF
+}
 # leave alone
 1;
 
